@@ -38,9 +38,13 @@ YFrameButton::YFrameButton(YFrameTitleBar* parent, char kind) :
 YFrameButton::~YFrameButton() {
 }
 
+YFrameTitleBar *YFrameButton::titlebar() const {
+    return reinterpret_cast<YFrameTitleBar*>(parent());
+}
+
 YFrameWindow *YFrameButton::getFrame() const {
-    return reinterpret_cast<YFrameTitleBar*>(parent())->getFrame();
-};
+    return titlebar()->getFrame();
+}
 
 bool YFrameButton::focused() const {
     return getFrame()->focused();
@@ -159,17 +163,19 @@ void YFrameButton::handleClick(const XButtonEvent &up, int count) {
     }
 }
 
-void YFrameButton::handleBeginDrag(const XButtonEvent &down, const XMotionEvent &/*motion*/) {
+bool YFrameButton::handleBeginDrag(const XButtonEvent &down, const XMotionEvent &/*motion*/) {
     bool dragButton = inrange(int(down.button), Button2, Button3);
     if (dragButton && getFrame()->canMove()) {
         if (!isPopupActive()) {
-            YFrameTitleBar* tbar = getFrame()->titlebar();
+            YFrameTitleBar* tbar = titlebar();
             getFrame()->startMoveSize(true, true,
                                       0, 0,
                                       down.x + x() + (tbar ? tbar->x() : 0),
                                       down.y + y() + (tbar ? tbar->y() : 0));
+            return true;
         }
     }
+    return false;
 }
 
 void YFrameButton::handleVisibility(const XVisibilityEvent& visib) {
